## Origin of example data

### Neurons
The example neurons provided are olfactory projection neurons [1] and were
manually reconstructed in an ssTEM volume of an adult fruit fly brain [2].

### Volumes
Example volumes provided are based on light microscopy images of the fruit
fly brain and were transformed into EM space. See the
[`nat`](https://github.com/jefferis/nat) ecosystem for R.
In particular [`nat.flybrains`](https://github.com/jefferislab/nat.flybrains).

### References
[1] Huoviala et al., bioRxiv. 2018. doi: 10.1101/394403. Neural circuit basis
of aversive odour processing in Drosophila from sensory input to descending
output.
[2] Zheng, Lauritzen et al., Cell. 2018 Jul 26;174(3):730-743.e22. doi: 10.1016/j.cell.2018.06.019. Epub 2018 Jul 19.
A Complete Electron Microscopy Volume of the Brain of Adult Drosophila melanogaster.

